@@ -100,13 +100,20 @@ set_credentials <- function(client_id, client_secret, tenant_id, region) {
   config <- list(
     tenant_id = tenant_id,
     region    = region,
-    token_url = "https://security.valdperformance.com/connect/token",
+    token_url = "https://auth.prd.vald.com/oauth/token",
     endpoints = endpoints
   )
 
   # Persist non-sensitive config to disk as JSON
   jsonlite::write_json(config, .vald_config_path(), auto_unbox = TRUE)
 
+  # KH added new logic here for Auth0 migration: clear any cached access token for this tenant
+  # Can probably remove the below a bit later
+  tryCatch(
+    keyring::key_delete(service = "valdr_token", username = tenant_id),
+    error = function(e) NULL
+  )
+
   # Load credentials into package environment to refresh state
   load_credentials()
 
@@ -204,7 +211,6 @@ load_credentials <- function(verbose = TRUE) {
 #' @export
 get_config <- function(safe = TRUE, quiet = FALSE) {
   if (is.null(.vald_api_env$config)) {
-    
     # Try to lazy load credentials if not already loaded in this session
     load_ok <- load_credentials(verbose = !quiet)
     if (!isTRUE(load_ok) || is.null(.vald_api_env$config)) {
