@@ -1,5 +1,5 @@
 # Test scenario of using bad credentials to make a call
-# Expect a 400 response
+# Expect a 401 response
 
 test_that("API credentials can be set", {
   # Uses credentials in local .Renviron file
@@ -13,6 +13,8 @@ test_that("API credentials can be set", {
 
   # Make a call with the bad credentials
   result <-
-    expect_error(get_forcedecks_data(),regexp = "^Bad Request \\(400\\)")
-  
-})
+    expect_error(get_forcedecks_data(),
+      "Unauthorized (401): Authentication failed. Please check your API credentials using `get_config()` and then `set_credentials()`.",
+      fixed = TRUE
+    )
+})
\ No newline at end of file
