@@ -3,6 +3,6 @@
 test_that("Write a dummy start date to config", {
   clear_config_file()
   reset_credentials()
-  result<-set_start_date(dummy_start_date)
+  result<-set_start_date(Sys.getenv("start_date"))
   expect_true(!is.null(result))
 })
\ No newline at end of file
