@@ -3,5 +3,5 @@ test_that("Read previously written dummy start date in config", {
   config_path <- file.path(Sys.getenv("HOME"), ".vald_config.json")
   data <- read_json(config_path)
 
-  expect_true(data$start_date == dummy_start_date)
+  expect_true(data$start_date == Sys.getenv("start_date"))
 })
\ No newline at end of file
